//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[ShantenWithoutGot](index.md)/[goodShapeAdvanceNum](good-shape-advance-num.md)

# goodShapeAdvanceNum

[common]\

@EncodeDefault

val [goodShapeAdvanceNum](good-shape-advance-num.md): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)?

好型进张数 仅当一向听时进行计算
